==> cucumber_1.0.2.orig.tar.gz: cucumber-1.0.2/lib/cucumber/wire_support/connection.rb <==
require 'timeout'
require 'cucumber/wire_support/wire_protocol'

module Cucumber
  module WireSupport
    class Connection
      class ConnectionError < StandardError; end
        
      include WireProtocol
      
      def initialize(config)
        @config = config
      end
      
      def call_remote(request_handler, message, params)
        packet = WirePacket.new(message, params)

        begin
          send_data_to_socket(packet.to_json)
          response = fetch_data_from_socket(@config.timeout(message))
          response.handle_with(request_handler)
        rescue Timeout::Error => e
          backtrace = e.backtrace ; backtrace.shift # because Timeout puts some wierd stuff in there
          raise Timeout::Error, "Timed out calling wire server with message '#{message}'", backtrace
        end
      end
      
      def exception(params)
        WireException.new(params, @config.host, @config.port)
      end

      private
      
      def send_data_to_socket(data)
        Timeout.timeout(@config.timeout) { socket.puts(data) }
      end

      def fetch_data_from_socket(timeout)
        raw_response = 
          if timeout == :never
            socket.gets
          else
            Timeout.timeout(timeout) { socket.gets }
          end
        WirePacket.parse(raw_response)
      end
      
      def socket
        @socket ||= TCPSocket.new(@config.host, @config.port)
      rescue Errno::ECONNREFUSED => exception
        raise(ConnectionError, "Unable to contact the wire server at #{@config.host}:#{@config.port}. Is it up?")
      end
    end
  end
end

==> cucumber_1.3.8.orig.tar.gz: cucumber-1.3.8/lib/cucumber/wire_support/connection.rb <==
require 'timeout'
require 'cucumber/wire_support/wire_protocol'

module Cucumber
  module WireSupport
    class Connection
      class ConnectionError < StandardError; end

      include WireProtocol

      def initialize(config)
        @config = config
      end

      def call_remote(request_handler, message, params)
        packet = WirePacket.new(message, params)

        begin
          send_data_to_socket(packet.to_json)
          response = fetch_data_from_socket(@config.timeout(message))
          response.handle_with(request_handler)
        rescue Timeout::Error => e
          backtrace = e.backtrace ; backtrace.shift # because Timeout puts some wierd stuff in there
          raise Timeout::Error, "Timed out calling wire server with message '#{message}'", backtrace
        end
      end

      def exception(params)
        WireException.new(params, @config)
      end

      private

      def send_data_to_socket(data)
        Timeout.timeout(@config.timeout('connect')) { socket.puts(data) }
      end

      def fetch_data_from_socket(timeout)
        raw_response =
          if timeout == :never
            socket.gets
          else
            Timeout.timeout(timeout) { socket.gets }
          end
        raise exception({'message' => "Remote Socket with #{@config.host}:#{@config.port} closed."}) if raw_response.nil?
        WirePacket.parse(raw_response)
      end

      def socket
        return @socket if @socket
        if @config.unix
          @socket = UNIXSocket.new(@config.unix)
        else
          @socket = TCPSocket.new(@config.host, @config.port)
        end
      rescue Errno::ECONNREFUSED => exception
        raise(ConnectionError, "Unable to contact the wire server at #{@config}. Is it up?")
      end
    end
  end
end
